##  Managing Notifications
To adjust notification settings, click Open Notification Settings. To learn more about configuring notifications, see [Notifications](https://help.sap.com/docs/leanix/ea/notifications?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust your notification preferences to stay informed about significant changes in your workspace, monitor tasks that need your attention, and stay updated on other relevant activities.").
Users with Admin rights can further configure notifications from the Notification Center. If you want to stop notifications for a particular workspace, disable the Microsoft Teams toggle in the Notification Center. To learn more, check [Notification Center.](https://help.sap.com/docs/leanix/ea/notifications-center?locale=en-US&state=PRODUCTION&version=CLOUD "Configure notification settings for your workspace.")
